#!/bin/sh

set -e
set -o pipefail

if [ $# -ne 2 ]
then
	echo "usage: $(basename "$0") environment region"
	exit 64
fi

ca_cert="${1}_ca/pki/ca.crt"
crl_pem="${1}_ca/pki/crl.pem"
cert="${1}_ca/pki/issued/${2}.${1}.crt"
key="${1}_ca/pki/private/${2}.${1}.key"
ta_secret="${1}_ca/pki/ta.key"

# reuse any extant quagga password
for v in "${1}"/group_vars/*vpcaccess*
do
	if [ -n "${quagga_password}" ]
	then
		echo "found multiple potential quagga passwords; the chosen one may not be correct" 1>&2
	fi
	quagga_password=$(awk '/QUAGGA_PASSWORD:/{print $2}' "${v}")
done
if [ -z "${quagga_password}" ]
then
	quagga_password=$(pwgen -y 16)
fi

function onlycert(){
	sed -n '/-----BEGIN /,/-----END /p' "$@"
}
function indent(){
	sed 's/^/  /' "$@"
}

cat<<EOF
---
QUAGGA_PASSWORD: "${quagga_password}"
ca_name: $1
ca_cert: |
$(indent "${ca_cert}")
crl_pem: |
$(indent "${crl_pem}")
cert: |
$(onlycert "${cert}" | indent)
key: |
$(indent "${key}")
ta_secret: |
$(indent "${ta_secret}")
EOF
